/*********************************************************************
 * Desktop Station Buzzer Library for Arduino
 *
 * Copyright (C) 2015 Yaasan
 * Not use for commercial use
 */

#include <avr/pgmspace.h>
#include <Arduino.h>
#include "DS_Buzzer.h"


DSBuzzer::DSBuzzer()
{
	pinMode(9, OUTPUT);
}

void DSBuzzer::Init()
{

	gTime_Interval = 0;
	gCount_length = 0xFFFF;
	gCount = 0;
	
	gSoundData.mNo = 0;
	gSoundData.mTone = 0;
	gSoundData.mInterval = 0; 
	gSoundData.mAnalog = true;
	gSoundData.mLength = 0;

}

void DSBuzzer::Register(byte inTone, byte inInterval, unsigned short inLength)
{
	gSoundData.mNo = 1;
	gSoundData.mTone = inTone;
	gSoundData.mInterval = inInterval; 
	gSoundData.mAnalog = true;
	gSoundData.mLength = inLength;
	
	//Start buzzer
	gCount_length = 0;
	gCount = 0;
	
}

void DSBuzzer::Register(byte inNo, unsigned short inLength)
{
	gSoundData.mNo = 1;
	gSoundData.mTone = pgm_read_byte(&buzzer_data[inNo * 2 + 0]);
	gSoundData.mInterval = pgm_read_byte(&buzzer_data[inNo * 2 + 1]);
	gSoundData.mAnalog = true;
	gSoundData.mLength = inLength;
	
	//Start buzzer
	gCount_length = 0;
	gCount = 0;
	
}

void DSBuzzer::soundWrite( int inPin, int inValue)
{
  if( gSoundData.mAnalog == true)
  {
    analogWrite(inPin, inValue);
  }
  else
  {
    digitalWrite(inPin, inValue);    
  }
  
  
}

void DSBuzzer::Scan() {
	// 100ms interval
	if( (millis() - gTime_Interval) >= 100)
	{
		if( gCount_length < gSoundData.mLength)
		{
			if( gCount <= gSoundData.mInterval)
			{
				soundWrite(9, 0);
			}
			else
			{
				soundWrite(9, gSoundData.mTone);
			}
			
			gCount++;
			
			if( gCount > (gSoundData.mInterval << 1))
			{
				gCount = 0; 
			}
			
			
			gCount_length++;
			
			//出力を停止
			if( gCount_length >= gSoundData.mLength)
			{
				soundWrite(9, 0);
			}

		}
		
		//Reset task
		gTime_Interval = millis();
	}
}
